==> deepin-screen-recorder_5.9.6.orig.tar.xz: deepin-screen-recorder-5.9.6/translations/deepin-screen-recorder_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Feu clic a la icona de la safata
o premeu la drecera de nou per aturar la gravació.</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Grava</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>No s&apos;ha pogut desar. Deseu-ho al directori personal.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vista</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Captura finalitzada</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>Seleccioneu l&apos;àrea</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Desa</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>S&apos;ha desat a %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignora</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Porta-retalls</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Es desa el fitxer de gravació de pantalla. Espereu, si us plau...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Com que l’efecte de finestra es desactiva durant el procés, s’ha d’aturar la gravació.</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Desfés</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Desa</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Surt</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Vista</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Gravació acabada</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>S&apos;ha desat a %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Grava</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>La Captura de pantalla s&apos;iniciarà d&apos;aquí a %1 segons</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Introduïu el text aquí</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Inicia/Captura de pantalla</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Surt/Desa</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>Dibuix</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Ajust de la mida</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configuració</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Inici ràpid</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Captura la finestra</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Captura de pantalla amb retard</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Captura de pantalla completa</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Surt</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Desa</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectangle</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>El·lipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Línia</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Llapis</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Suprimeix</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Desfés</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Augmenta l&apos;alçada cap amunt</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Augmenta l&apos;alçada cap avall</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Augmenta l&apos;amplada a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Augmenta l&apos;amplada a la dreta</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Disminueix l&apos;alçada cap amunt</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Disminueix l&apos;alçada cap avall</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Disminueix l&apos;amplada a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Disminueix l&apos;amplada a la dreta</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostra les dreceres</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>So</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Pulsació</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Càmera web</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Inicia la gravació</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcions</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Inici / gravació</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Ratolí</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Difumina</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mosaic</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>So activat</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Micròfon</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Àudio del sistema</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>So desactivat</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Mostra la pulsació de tecles</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Oculta la pulsació de tecles</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Càmera web activada</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Càmera web desactivada</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Mostra els clics</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcions</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectangle</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>El·lipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Línia</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Fletxa</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Llapis</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Desa a</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Escriptori</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Fotos</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Porta-retalls</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Mostra el punter</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Ratolí</translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation>Mostra&apos;n el punter</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Ajusteu l&apos;àrea de gravació dins %1*%2 per obtenir un efecte de vídeo millor.</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>Gravacions</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder_5.10.15.orig.tar.xz: deepin-screen-recorder-5.10.15/translations/deepin-screen-recorder_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Feu clic a la icona de la safata
o premeu la drecera de nou per aturar la gravació.</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>No gireu la pantalla durant la gravació.</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Grava</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>No s&apos;ha pogut desar. Deseu-ho al directori personal.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vista</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Captura acabada</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>Seleccioneu l&apos;àrea</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Desa</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>S&apos;ha desat a %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignora</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Porta-retalls</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Es desa el fitxer de gravació de pantalla. Espereu, si us plau...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Com que l’efecte de finestra es desactiva durant el procés, s’ha d’aturar la gravació.</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>The screenshot has been saved in the album</source>
        <translation>La captura s&apos;ha desat a l&apos;àlbum.</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation>Ha fallat la captura</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Captura de desplaçament</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Desfés</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Desa</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Surt</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Vista</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Gravació acabada</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>S&apos;ha desat a %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Grava</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>La Captura de pantalla s&apos;iniciarà d&apos;aquí a %1 segons</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Obteniu ajuda</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Ha fallat fer una captura de pantalla contínua.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>S&apos;ha arribat al capdavall de l&apos;àrea de desplaçament.</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>S&apos;ha arribat a l&apos;extensió màxima.</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>ajustar l&apos;àrea de captura</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Feu girar la roda del ratolí o cliqueu per fer una captura de pantalla de desplaçament.</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Reduïu la velocitat del desplaçament.</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Àrea no vàlida, cliqueu per</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Introduïu el text aquí</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Inicia/Captura de pantalla</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Surt/Desa</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Ajust de la mida</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configuració</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Inici ràpid</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Captura la finestra</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Captura de pantalla amb retard</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Captura de pantalla completa</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Surt</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Desa</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectangle</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>El·lipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Línia</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Llapis</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Suprimeix</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Desfés</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Augmenta l&apos;alçada cap amunt</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Augmenta l&apos;alçada cap avall</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Augmenta l&apos;amplada a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Augmenta l&apos;amplada a la dreta</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Disminueix l&apos;alçada cap amunt</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Disminueix l&apos;alçada cap avall</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Disminueix l&apos;amplada a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Disminueix l&apos;amplada a la dreta</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostra les dreceres</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>So</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Pulsació</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Càmera web</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Inicia la gravació</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcions</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Inici / gravació</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Ratolí</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Eines</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extreu-ne el text</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Captura de desplaçament</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Fixa les captures</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Difumina</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mosaic</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>So activat</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Micròfon</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Àudio del sistema</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>So desactivat</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Mostra la pulsació de tecles</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Oculta la pulsació de tecles</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Càmera web activada</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Càmera web desactivada</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Mostra els clics</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcions</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectangle</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>El·lipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Línia</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Fletxa</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Llapis</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Desa a</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Escriptori</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Fotos</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Porta-retalls</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Mostra el punter</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Ratolí</translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation>Mostra&apos;n el punter</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Extreu-ne el text</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Captura de desplaçament</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Fixa les captures</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Ajusteu l&apos;àrea de gravació dins %1*%2 per obtenir un efecte de vídeo millor.</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Actualment no s&apos;admet la gravació de pantalla</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Surt</translation>
    </message>
</context>
</TS>
